@@ -19,16 +19,11 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-class BoardListView < KDE::ListView
+class BoardListView < Qt::TreeWidget
   slots 'load_board_list()'
-  slots 'show_board(QListViewItem*)'
-  slots 'context_menu(QListViewItem*,const QPoint&,int)'
-
-  POPUP_OPEN_WITH_WEB_BROWSER = 0
-  POPUP_COPY_URL = 1
-  POPUP_COPY_TITLE_AND_URL = 2
-  POPUP_ADD_TO_FAVORITE = 3
-  POPUP_DELETE_FROM_FAVORITE = 4
+  slots 'show_board(QTreeWidgetItem*)'
+  slots 'add_to_favorite()', 'delete_from_favorite()'
+  slots 'copy_url()', 'open_with_web_browser()', 'copy_title_and_url()'
 
   COLUMN_TITLE = 0
   COLUMN_URL = 1
@@ -37,13 +32,10 @@ class BoardListView < KDE::ListView
     super(parent)
 
     setRootIsDecorated(true)
-    setSorting(-1)
-    addColumn("board name")
+    setHeaderLabels(["board name"])
 
-    connect(self, SIGNAL("clicked(QListViewItem*)"),
-            self, SLOT("show_board(QListViewItem*)"))
-    connect(self, SIGNAL("contextMenuRequested(QListViewItem*,const QPoint&,int)"),
-            self, SLOT("context_menu(QListViewItem*,const QPoint&,int)"))
+    connect(self, SIGNAL("itemClicked(QTreeWidgetItem*,int)"),
+            self, SLOT("show_board(QTreeWidgetItem*)"))
 
     str = nil
     begin
@@ -91,20 +83,26 @@ class BoardListView < KDE::ListView
 
     clear
 
-    group_list.reverse.each {|group|
-      item = KDE::ListViewItem.new(self, group.name)
-      group.list.reverse.each {|board|
-        KDE::ListViewItem.new(item, board.title, board.url)
-      }
-    }
+    @favorite_item = Qt::TreeWidgetItem.new(self)
+    @favorite_item.setText(0, "お気に入り")
+    load_favorites
 
     kitabbs_url = "http://jbbs.livedoor.jp/computer/18420/"
     BoardManager.instance.register_name(kitabbs_url, "Kita板")
     BoardManager.instance.register_url("jbbs.livedoor.jp", "computer_18420", kitabbs_url)
-    KDE::ListViewItem.new(self, "Kita板", "http://jbbs.livedoor.jp/computer/18420/")
+    item = Qt::TreeWidgetItem.new(self)
+    item.setText(0, "Kita板")
+    item.setText(1, "http://jbbs.livedoor.jp/computer/18420/")
 
-    @favorite_item = KDE::ListViewItem.new(self, "お気に入り")
-    load_favorites
+    group_list.each {|group|
+      parent_item = Qt::TreeWidgetItem.new(self)
+      parent_item.setText(0, group.name)
+      group.list.each {|board|
+        item = Qt::TreeWidgetItem.new(parent_item)
+        item.setText(0, board.title)
+        item.setText(1, board.url)
+      }
+    }
   end
 
   def show_board(item)
@@ -116,64 +114,70 @@ class BoardListView < KDE::ListView
     ViewMediator.show_board(board_url)
   end
 
-  def context_menu(item, pos, col)
-    return unless item
-
-    board_url = item.text(COLUMN_URL)
-    board_title = item.text(COLUMN_TITLE)
-
-    popup = KDE::PopupMenu.new
-    popup.insertItem("ウェブブラウザで開く", POPUP_OPEN_WITH_WEB_BROWSER)
-    popup.insertItem("Copy URL", POPUP_COPY_URL)
-    popup.insertItem("Copy title and URL", POPUP_COPY_TITLE_AND_URL)
-    if item.parent == @favorite_item then
-      popup.insertItem("お気に入りから削除", POPUP_DELETE_FROM_FAVORITE)
+  def contextMenuEvent(event)
+    popup = KDE::Menu.new
+    popup.addAction("ウェブブラウザで開く", self, SLOT('open_with_web_browser()'))
+    popup.addAction("Copy URL", self, SLOT('copy_url()'))
+    popup.addAction("Copy title and URL", self, SLOT('copy_title_and_url()'))
+    if currentItem.parent == @favorite_item then
+      popup.addAction("お気に入りから削除", self, SLOT('delete_from_favorite()'))
     else
-      popup.insertItem("お気に入りに追加", POPUP_ADD_TO_FAVORITE)
-    end
-
-    clipboard = Qt::Application.clipboard
-    case popup.exec(pos)
-    when POPUP_OPEN_WITH_WEB_BROWSER
-      $app.invokeBrowser(board_url)
-    when POPUP_COPY_URL
-      clipboard.setText(board_url, Qt::Clipboard::Clipboard)
-      clipboard.setText(board_url, Qt::Clipboard::Selection)
-    when POPUP_COPY_TITLE_AND_URL
-      cliptext = board_title + "\n" + board_url
-      clipboard.setText(cliptext, Qt::Clipboard::Clipboard)
-      clipboard.setText(cliptext, Qt::Clipboard::Selection)
-    when POPUP_ADD_TO_FAVORITE
-      add_to_favorite(board_url)
-    when POPUP_DELETE_FROM_FAVORITE
-      delete_from_favorite(item, board_url)
+      popup.addAction("お気に入りに追加", self, SLOT('add_to_favorite()'))
     end
+    popup.exec(event.globalPos())
   end
 
-  def add_to_favorite(board_url)
+  def copy_url
+    board_url = currentItem.text(COLUMN_URL)
+    clipboard = Qt::Application.clipboard
+    clipboard.setText(board_url, Qt::Clipboard::Clipboard)
+    clipboard.setText(board_url, Qt::Clipboard::Selection)
+  end
+
+  def copy_title_and_url
+    board_url = currentItem.text(COLUMN_URL)
+    board_title = currentItem.text(COLUMN_TITLE)
+    clipboard = Qt::Application.clipboard
+    cliptext = board_title + "\n" + board_url
+    clipboard.setText(cliptext, Qt::Clipboard::Clipboard)
+    clipboard.setText(cliptext, Qt::Clipboard::Selection)
+  end
+
+  def open_with_web_browser
+    board_url = currentItem.text(COLUMN_URL)
+    KDE::ToolInvocation.invokeBrowser(board_url)
+  end
+
+  def add_to_favorite
+    board_url = currentItem.text(COLUMN_URL)
     board_type = Util.board_url_to_board_type_name(board_url)
     board_id = Util.board_url_to_board_id(board_url)
     registered = FavoriteBoards.instance.register(board_type, board_id)
 
     if registered then
       board_name = BoardManager.instance.get_name(board_url)
-      KDE::ListViewItem.new(@favorite_item, board_name, board_url)
+      board_item = Qt::TreeWidgetItem.new(@favorite_item)
+      board_item.setText(0, board_name)
+      board_item.setText(1, board_url)
     end
   end
 
-  def delete_from_favorite(item, board_url)
+  def delete_from_favorite()
+    board_url = currentItem.text(COLUMN_URL)
     board_type = Util.board_url_to_board_type_name(board_url)
     board_id = Util.board_url_to_board_id(board_url)
     FavoriteBoards.instance.delete(board_type, board_id)
 
-    @favorite_item.takeItem(item)
+    @favorite_item.removeChild(currentItem)
   end
 
   def load_favorites
     FavoriteBoards.instance.each {|type, id|
       board_url = BoardManager.instance.get_url(type, id)
       board_name = BoardManager.instance.get_name(board_url)
-      KDE::ListViewItem.new(@favorite_item, board_name, board_url)
+      board_item = Qt::TreeWidgetItem.new(@favorite_item)
+      board_item.setText(0, board_name)
+      board_item.setText(1, board_url)
     }
   end
 end
