@@ -25,83 +25,86 @@ class Config
   include Singleton
 
   def initialize
-    @config = KDE::SimpleConfig.new(ENV['HOME'] + "/.kita/config")
+    @config = KDE::Config.new(ENV['HOME'] + "/.kita/config")
   end
 
   def user_id
-    @config.setGroup("Account")
-    @config.readEntry("UserId")
+    config = @config.group("Account")
+    config.readEntry("UserId", "")
   end
 
   def user_id=(user_id)
-    @config.setGroup("Account")
-    @config.writeEntry("UserId", user_id)
-    @config.sync
+    config = @config.group("Account")
+    config.writeEntry("UserId", user_id)
+    config.sync
   end
 
   def password
-    @config.setGroup("Account")
-    @config.readEntry("Password")
+    config = @config.group("Account")
+    config.readEntry("Password", "")
   end
 
   def password=(password)
-    @config.setGroup("Account")
-    @config.writeEntry("Password", password)
-    @config.sync
+    config = @config.group("Account")
+    config.writeEntry("Password", password)
+    config.sync
   end
 
   def auto_login
-    @config.setGroup("Account")
-    @config.readBoolEntry("AutoLogin")
+    config = @config.group("Account")
+    config.readEntry("AutoLogin", true)
   end
 
   def auto_login=(flag)
-    @config.setGroup("Account")
-    @config.writeEntry("AutoLogin", flag)
-    @config.sync
+    config = @config.group("Account")
+    config.writeEntry("AutoLogin", flag)
+    config.sync
   end
 
   def default_name
-    @config.setGroup("Write")
-    @config.readEntry("DefaultName")
+    config = @config.group("Write")
+    config.readEntry("DefaultName", "")
   end
 
   def default_name=(name)
-    @config.setGroup("Write")
-    @config.writeEntry("DefaultName", name)
-    @config.sync
+    config = @config.group("Write")
+    config.writeEntry("DefaultName", name)
+    config.sync
   end
 
   def default_mail
-    @config.setGroup("Write")
-    @config.readEntry("DefaultMail")
+    config = @config.group("Write")
+    config.readEntry("DefaultMail", "")
   end
 
   def default_mail=(mail)
-    @config.setGroup("Write")
-    @config.writeEntry("DefaultMail", mail)
-    @config.sync
+    config = @config.group("Write")
+    config.writeEntry("DefaultMail", mail)
+    config.sync
   end
 
   def kotehan
-    @config.setGroup("Write")
-    @config.readListEntry("Kotehan")
+    config = @config.group("Write")
+    config.readEntry("Kotehan", [])
   end
 
   def kotehan=(list)
-    @config.setGroup("Write")
-    @config.writeEntry("Kotehan", list)
-    @config.sync
+    config = @config.group("Write")
+    config.writeEntry("Kotehan", list)
+    config.sync
   end
 
   def thread_font
-    @config.setGroup("Face")
-    @config.readFontEntry("ThreadFont")
+    config = @config.group("Face")
+    font_str = config.readEntry("ThreadFont", "")
+    font = Qt::Font.new
+    font.fromString(font_str)
+    font
   end
 
   def thread_font=(font)
-    @config.setGroup("Face")
-    @config.writeEntry("ThreadFont", font)
-    @config.sync
+    config = @config.group("Face")
+    config.writeEntry("ThreadFont", font.toString)
+    config.sync
   end
 end
