@@ -162,7 +162,7 @@ class DatInfo
 
   def save_index
     index_path = Util.dat_url_to_index_path(@dat_url)
-    config = KDE::Config.new(index_path)
+    config = KDE::Config.new(index_path).group("")
 
     config.writeEntry("ThreadName", @thread_name) if @thread_name
     config.writeEntry("ResNum", @comments.size)
