@@ -19,22 +19,36 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-class PreferenceDialog < KDE::DialogBase
+class PreferenceDialog < KDE::PageDialog
   slots 'save_config()'
 
   def initialize(parent)
-    super(KDE::DialogBase::IconList, 0, parent, "settings")
+    super(parent)
 
-    @general_vbox = addVBoxPage("General", nil, KDE::SmallIcon("configure", 32))
+    resize(600, 400)
 
-    @face_vbox = addVBoxPage("外観", nil, KDE::SmallIcon("configure", 32))
-    @face_page = FacePage.new(@face_vbox)
+#    addPage(nil, "General")
 
-    @account_vbox = addVBoxPage("Account", nil, KDE::SmallIcon("identity", 32))
-    @account_page = AccountPage.new(@account_vbox)
+    @face_page = Ui::FacePage.new
+    @face_page.setupUi(@face_page)
+    @face_page_item = KDE::PageWidgetItem.new(@face_page, "外観")
+    @face_page_item.setHeader("外観")
+    @face_page_item.setIcon(KDE::Icon.new("configure"))
+    addPage(@face_page_item)
 
-    @write_vbox = addVBoxPage("Write", nil, KDE::SmallIcon("edit", 32))
-    @write_page = WritePage.new(@write_vbox)
+    @account_page = Ui::AccountPage.new
+    @account_page.setupUi(@account_page)
+    @account_page_item = KDE::PageWidgetItem.new(@account_page, "Account")
+    @account_page_item.setHeader("Account")
+    @account_page_item.setIcon(KDE::Icon.new("network-connect"))
+    addPage(@account_page_item)
+
+    @write_page = Ui::WritePage.new
+    @write_page.setupUi(@write_page)
+    @write_page_item = KDE::PageWidgetItem.new(@write_page, "Write")
+    @write_page_item.setHeader("Write")
+    @write_page_item.setIcon(KDE::Icon.new("document-properties"))
+    addPage(@write_page_item)
 
     connect(self, SIGNAL("okClicked()"), self, SLOT("save_config()"))
 
@@ -49,7 +63,7 @@ class PreferenceDialog < KDE::DialogBase
     @account_page.autologin_check.setChecked(config.auto_login)
     @write_page.default_name_line.text = config.default_name
     @write_page.default_mail_line.text = config.default_mail
-    @write_page.kotehan_edit.text = config.kotehan.join("\n")
+    @write_page.kotehan_edit.setPlainText(config.kotehan.join("\n"))
   end
 
   def save_config
@@ -58,7 +72,7 @@ class PreferenceDialog < KDE::DialogBase
     auto_login = @account_page.autologin_check.checked
     default_name = @write_page.default_name_line.text
     default_mail = @write_page.default_mail_line.text
-    kotehan = @write_page.kotehan_edit.text.split("\n").grep(/^.+$/)
+    kotehan = @write_page.kotehan_edit.toPlainText.split("\n").grep(/^.+$/)
     thread_font = @face_page.thread_font_requester.font
 
     config = Config.instance
