@@ -20,12 +20,12 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 class ThreadListView < Qt::Widget
-  slots 'show_thread(QListViewItem*)'
+  slots 'show_thread(QTreeWidgetItem*)'
   slots 'search()'
   slots 'filter(bool)'
-  slots 'context_menu(QListViewItem*,const QPoint&,int)'
   slots 'remove_self()'
   slots 'reload()'
+  slots 'copy_url()', 'open_with_web_browser()', 'copy_title_and_url()'
 
   SUBJECT_TXT_REGEXP1 = /((\d+)\.cgi),(.*)\((\d+)\)/
   SUBJECT_TXT_REGEXP2 = /((\d+)\.dat)<>(.*)\((\d+)\)/
@@ -45,19 +45,18 @@ class ThreadListView < Qt::Widget
   ORDER_READ = "1"
   ORDER_NORMAL = "2"
 
-  POPUP_OPEN_WITH_WEB_BROWSER = 0
-  POPUP_COPY_URL = 1
-  POPUP_COPY_TITLE_AND_URL = 2
+  NULL_ICON = Qt::Icon.new
 
   def initialize(parent)
     super(parent)
 
     main_layout = Qt::VBoxLayout.new(self)
-    tool_layout = Qt::HBoxLayout.new(main_layout)
+    tool_layout = Qt::HBoxLayout.new
+    main_layout.addLayout(tool_layout)
     @search_line = Qt::LineEdit.new(self)
     tool_layout.addWidget(@search_line)
     @search_button = Qt::ToolButton.new(self)
-    @search_button.setPixmap(KDE::SmallIcon("find"))
+    @search_button.setIcon(KDE::Icon.new("edit-find"))
     @search_button.setEnabled(false)
     tool_layout.addWidget(@search_button)
     connect(@search_button, SIGNAL("clicked()"),
@@ -66,47 +65,36 @@ class ThreadListView < Qt::Widget
             self, SLOT("search()"))
 
     @filter_button = Qt::ToolButton.new(self)
-    @filter_button.setPixmap(KDE::SmallIcon("filter"))
-    @filter_button.setToggleButton(true)
+    @filter_button.setIcon(KDE::Icon.new("view-filter"))
+    @filter_button.setCheckable(true)
     @filter_button.setEnabled(false)
     tool_layout.addWidget(@filter_button)
     connect(@filter_button, SIGNAL("toggled(bool)"),
             self, SLOT("filter(bool)"))
 
     @reload_button = Qt::ToolButton.new(self)
-    @reload_button.setPixmap(KDE::SmallIcon("reload"))
+    @reload_button.setIcon(KDE::Icon.new("vcs_update"))
     @reload_button.setEnabled(false)
     tool_layout.addWidget(@reload_button)
     connect(@reload_button, SIGNAL("clicked()"), self, SLOT("reload()"))
 
     @close_button = Qt::ToolButton.new(self)
-    @close_button.setPixmap(KDE::SmallIcon("fileclose"))
+    @close_button.setIcon(KDE::Icon.new("dialog-close"))
     @close_button.setEnabled(false)
     tool_layout.addWidget(@close_button)
     connect(@close_button, SIGNAL("clicked()"), self, SLOT("remove_self()"))
 
-    @list = KDE::ListView.new(self)
+    @list = Qt::TreeWidget.new(self)
     main_layout.addWidget(@list)
 
-    connect(@list, SIGNAL("clicked(QListViewItem*)"),
-            self, SLOT("show_thread(QListViewItem*)"))
-    connect(@list, SIGNAL("contextMenuRequested(QListViewItem*,const QPoint&,int)"),
-            self, SLOT("context_menu(QListViewItem*,const QPoint&,int)"))
+    connect(@list, SIGNAL("itemClicked(QTreeWidgetItem*,int)"),
+            self, SLOT("show_thread(QTreeWidgetItem*)"))
 
-    @list.addColumn("")
-    @list.addColumn("No.")
-    @list.addColumn(" ")
-    @list.addColumn("Thread name")
-    @list.addColumn("Res")
-    @list.addColumn("Read")
-    @list.addColumn("Unread")
-    @list.addColumn("Open time")
-    @list.addColumn("Thread speed")
-#    @list.addColumn("Thread url")
-#    @list.setSorting(-1)
+    @list.setHeaderLabels(["", "No.", " ", "Thread name", "レス", "既読", "未読", "Open time", "Thread speed"])
     @list.setAllColumnsShowFocus(true)
-
-    @list.header.setStretchEnabled(true, COLUMN_TITLE)
+    @list.setRootIsDecorated(false)
+    @list.setSortingEnabled(true)
+#    @list.header.setStretchEnabled(true, COLUMN_TITLE)
 
     # search
     @prev_search_text = nil
@@ -128,6 +116,14 @@ class ThreadListView < Qt::Widget
       str = Downloader.download_subject_txt_jbbs(subject_txt_url)
     end
 
+    if str.size == 0
+      Qt::MessageBox::warning(self,
+                              "警告",
+                              "subject.txtが空です。板が移転した可能性が高いです。",
+                              Qt::MessageBox::Ok, Qt::MessageBox::NoButton)
+      return
+    end
+
     str.each {|line|
       if SUBJECT_TXT_REGEXP1.match(line) || SUBJECT_TXT_REGEXP2.match(line)
         dat_file_name = Regexp.last_match(1)
@@ -144,7 +140,7 @@ class ThreadListView < Qt::Widget
 
     @list.clear
 
-    prev_item = nil
+    prev_item = 0
     thread_list.each_with_index {|thread, i|
       item = ThreadListViewItem.new(@list, prev_item)
       item.setText(COLUMN_NO, "%4s" % (i+1))
@@ -157,10 +153,10 @@ class ThreadListView < Qt::Widget
       item.setText(COLUMN_URL, thread.dat_url)
 
       if thread.res_num > thread.read_num && thread.read_num != 0 then
-        item.setPixmap(COLUMN_MARK, Qt::Pixmap.new("unread.png"))
+        item.setIcon(COLUMN_MARK, Qt::Icon.new("unread.png"))
         item.setText(COLUMN_MARKORDER, ORDER_UNREAD)
       elsif thread.res_num == thread.read_num then
-        item.setPixmap(COLUMN_MARK, Qt::Pixmap.new("read.png"))
+        item.setIcon(COLUMN_MARK, Qt::Icon.new("read.png"))
         item.setText(COLUMN_MARKORDER, ORDER_READ)
       else
         item.setText(COLUMN_MARKORDER, ORDER_NORMAL)
@@ -169,10 +165,23 @@ class ThreadListView < Qt::Widget
       prev_item = item
     }
 
+    resize_columns
     ViewMediator.set_url(url)
     enable_buttons
   end
 
+  def resize_columns
+    @list.resizeColumnToContents(COLUMN_MARK)
+    @list.resizeColumnToContents(COLUMN_NO)
+    @list.resizeColumnToContents(COLUMN_SEARCH)
+    @list.resizeColumnToContents(COLUMN_TITLE)
+    @list.resizeColumnToContents(COLUMN_RESNUM)
+    @list.resizeColumnToContents(COLUMN_READNUM)
+    @list.resizeColumnToContents(COLUMN_UNREADNUM)
+    @list.resizeColumnToContents(COLUMN_OPENTIME)
+    @list.resizeColumnToContents(COLUMN_SPEED)
+  end
+
   def show_thread(item)
     return if item == nil
 
@@ -189,22 +198,22 @@ class ThreadListView < Qt::Widget
     elsif str != ""
       search_new(str)
       @prev_search_text = str
-      @filter_button.setOn(true)
+      @filter_button.toggled(true)
       filter(true)
     else
       search_clear
-      @filter_button.setOn(false)
+      @filter_button.toggled(false)
     end
   end
 
   def filter(on)
-    it = Qt::ListViewItemIterator.new(@list)
+    it = Qt::TreeWidgetItemIterator.new(@list)
     while it.current do
       item = it.current
-      if on && ! item.pixmap(COLUMN_SEARCH) then
-        item.setVisible(false)
+      if on && item.icon(COLUMN_SEARCH).isNull then
+        item.setHidden(true)
       else
-        item.setVisible(true)
+        item.setHidden(false)
       end
       it += 1
     end
@@ -215,10 +224,10 @@ class ThreadListView < Qt::Widget
     @hit_list_index = 0
     @prev_search_text = nil
 
-    it = Qt::ListViewItemIterator.new(@list)
+    it = Qt::TreeWidgetItemIterator.new(@list)
     while it.current do
       item = it.current
-      item.setPixmap(COLUMN_SEARCH, Qt::Pixmap.new)
+      item.setIcon(COLUMN_SEARCH, NULL_ICON)
       it += 1
     end
   end
@@ -227,11 +236,11 @@ class ThreadListView < Qt::Widget
     @hit_list.clear
     @hit_list_index = 0
 
-    it = Qt::ListViewItemIterator.new(@list)
+    it = Qt::TreeWidgetItemIterator.new(@list)
     regexp = Regexp.new(str, Regexp::IGNORECASE)
     while it.current do
       item = it.current
-      item.setPixmap(COLUMN_SEARCH, Qt::Pixmap.new) # clear
+      item.setIcon(COLUMN_SEARCH, NULL_ICON)
       title = item.text(COLUMN_TITLE)
 
       if title.match(regexp) then
@@ -242,7 +251,7 @@ class ThreadListView < Qt::Widget
     end
 
     @hit_list.each {|item|
-      item.setPixmap(COLUMN_SEARCH, KDE::SmallIcon("find"))
+      item.setIcon(COLUMN_SEARCH, KDE::Icon.new("edit-find"))
     }
   end
 
@@ -257,30 +266,36 @@ class ThreadListView < Qt::Widget
     end
   end
 
-  def context_menu(item, pos, col)
-    return unless item
+  def contextMenuEvent(event)
+    popup = KDE::Menu.new
+    popup.addAction("ウェブブラウザで開く", self, SLOT('open_with_web_browser()'))
+    popup.addAction("Copy URL", self, SLOT('copy_url()'))
+    popup.addAction("Copy title and URL", self, SLOT('copy_title_and_url()'))
+    popup.exec(event.globalPos())
+  end
 
-    dat_url = item.text(COLUMN_URL)
+  def copy_url
+    dat_url = @list.currentItem.text(COLUMN_URL)
     thread_url = Util.dat_url_to_thread_url(dat_url)
-    thread_title = item.text(COLUMN_TITLE)
-
-    popup = KDE::PopupMenu.new
-    popup.insertItem("ウェブブラウザで開く", POPUP_OPEN_WITH_WEB_BROWSER)
-    popup.insertItem("Copy URL", POPUP_COPY_URL)
-    popup.insertItem("Copy title and URL", POPUP_COPY_TITLE_AND_URL)
-
     clipboard = Qt::Application.clipboard
-    case popup.exec(pos)
-    when POPUP_OPEN_WITH_WEB_BROWSER
-      $app.invokeBrowser(thread_url)
-    when POPUP_COPY_URL
-      clipboard.setText(thread_url, Qt::Clipboard::Clipboard)
-      clipboard.setText(thread_url, Qt::Clipboard::Selection)
-    when POPUP_COPY_TITLE_AND_URL
-      cliptext = thread_title + "\n" + thread_url
-      clipboard.setText(cliptext, Qt::Clipboard::Clipboard)
-      clipboard.setText(cliptext, Qt::Clipboard::Selection)
-    end
+    clipboard.setText(thread_url, Qt::Clipboard::Clipboard)
+    clipboard.setText(thread_url, Qt::Clipboard::Selection)
+  end
+
+  def copy_title_and_url
+    dat_url = @list.currentItem.text(COLUMN_URL)
+    thread_url = Util.dat_url_to_thread_url(dat_url)
+    thread_title = @list.currentItem.text(COLUMN_TITLE)
+    clipboard = Qt::Application.clipboard
+    cliptext = thread_title + "\n" + thread_url
+    clipboard.setText(cliptext, Qt::Clipboard::Clipboard)
+    clipboard.setText(cliptext, Qt::Clipboard::Selection)
+  end
+
+  def open_with_web_browser
+    dat_url = @list.currentItem.text(COLUMN_URL)
+    thread_url = Util.dat_url_to_thread_url(dat_url)
+    KDE::ToolInvocation.invokeBrowser(thread_url)
   end
 
   def remove_self
@@ -303,7 +318,7 @@ class ThreadListView < Qt::Widget
   end
 end
 
-class ThreadListViewItem < KDE::ListViewItem
+class ThreadListViewItem < Qt::TreeWidgetItem
   def compare(item, col, ascending)
     case col
     when ThreadListView::COLUMN_MARK
