@@ -37,7 +37,7 @@ class ThreadView < Qt::Widget
     layout.addLayout(buttons_layout)
 
     @write_button = Qt::ToolButton.new(self)
-    @write_button.setPixmap(KDE::SmallIcon("pencil"))
+    @write_button.setIcon(KDE::Icon.new("document-sign"))
     @write_button.setEnabled(false)
     buttons_layout.addWidget(@write_button)
     connect(@write_button, SIGNAL("clicked()"), self, SLOT("show_write_dialog()"))
@@ -48,13 +48,13 @@ class ThreadView < Qt::Widget
     connect(@search_line, SIGNAL("returnPressed()"), self, SLOT("search()"))
 
     @reload_button = Qt::ToolButton.new(self)
-    @reload_button.setPixmap(KDE::SmallIcon("reload"))
+    @reload_button.setIcon(KDE::Icon.new("vcs_update"))
     @reload_button.setEnabled(false)
     buttons_layout.addWidget(@reload_button)
     connect(@reload_button, SIGNAL("clicked()"), self, SLOT("reload()"))
 
     @delete_button = Qt::ToolButton.new(self)
-    @delete_button.setPixmap(KDE::SmallIcon("edittrash"))
+    @delete_button.setIcon(KDE::Icon.new("trash-empty"))
     @delete_button.setEnabled(false)
     buttons_layout.addWidget(@delete_button)
     connect(@delete_button, SIGNAL("clicked()"), self, SLOT("delete()"))
@@ -65,7 +65,7 @@ class ThreadView < Qt::Widget
     buttons_layout.addItem(spacer)
 
     @close_button = Qt::ToolButton.new(self)
-    @close_button.setPixmap(KDE::SmallIcon("fileclose"))
+    @close_button.setIcon(KDE::Icon.new("dialog-close"))
     @close_button.setEnabled(false)
     buttons_layout.addWidget(@close_button)
     connect(@close_button, SIGNAL("clicked()"), self, SLOT("remove_self()"))
