@@ -265,8 +265,8 @@ module Util
   def self.server_time(dat_url)
     index_path = dat_url_to_index_path(dat_url)
 
-    config = KDE::Config.new(index_path)
-    config.readEntry("Date")
+    config = KDE::Config.new(index_path).group("")
+    config.readEntry("Date", 0)
   end
 
   def self.to_plain(html)
